@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -12,8 +10,12 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+__all__ = ['__version__']
+
 import pbr.version
 
-
-__version__ = pbr.version.VersionInfo(
-    'congressclient').version_string()
+version_info = pbr.version.VersionInfo('python-congressclient')
+try:
+    __version__ = version_info.version_string()
+except AttributeError:
+    __version__ = None
